pub struct XdgActivationV1 { /* private fields */ }Expand description
interface for activating surfaces
A global interface used for informing the compositor about applications being activated or started, or for applications to request to be activated.
See also the Request enum for this interface.